@@ -184,7 +184,7 @@ class Worker:
                     "FailureMessage": unhandled_exception_message, 
                     "StackTrace": ""
                 }
-                self.table_client.insert_entity(failure_table, function_failure_entity)
+                self.table_client.insert_or_replace_entity(failure_table, function_failure_entity)
                 self.poison_queue.delete_message(msg)
         except ResourceNotFoundError:
             pass
@@ -250,7 +250,7 @@ class Worker:
                 
             request_entity['Offset'] = offset + len(result)
             request_entity['Batch'] = batch_count + 1
-            request_entity['NextChunk'] = json.dumps(next_chunk)
+            request_entity['NextChunk'] = json.dumps(next_chunk, ensure_ascii=False)
             self.table_client.update_entity(self.metadata_table_name, request_entity)
             self._enqueue(request_id)
         else:
